import { pgTable, text, serial, integer, boolean, timestamp, jsonb } from "drizzle-orm/pg-core";
import { createInsertSchema } from "drizzle-zod";
import { z } from "zod";

// User schema
export const users = pgTable("users", {
  id: serial("id").primaryKey(),
  username: text("username").notNull().unique(),
  password: text("password").notNull(),
  isAdmin: boolean("is_admin").default(true).notNull(),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertUserSchema = createInsertSchema(users).pick({
  username: true,
  password: true,
});

// Content Categories schema
export const categories = pgTable("categories", {
  id: serial("id").primaryKey(),
  name: text("name").notNull().unique(),
  type: text("type").notNull(), // movie, series, channel, match
});

export const insertCategorySchema = createInsertSchema(categories);

// Subcategories schema
export const subcategories = pgTable("subcategories", {
  id: serial("id").primaryKey(),
  name: text("name").notNull(),
  description: text("description"),
  thumbnail: text("thumbnail"),
  banner: text("banner"),
  type: text("type").notNull(), // movie, series
  parentCategoryId: integer("parent_category_id").notNull(), // References categories.id
  isActive: boolean("is_active").default(true).notNull(),
  displayOrder: integer("display_order").default(0),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertSubcategorySchema = createInsertSchema(subcategories).omit({
  id: true,
  createdAt: true,
});

// Movies schema
export const movies = pgTable("movies", {
  id: serial("id").primaryKey(),
  title: text("title").notNull(),
  description: text("description"),
  year: integer("year"),
  runtime: integer("runtime"),
  poster: text("poster"),
  backdrop: text("backdrop"),
  genre: text("genre"),
  contentRating: text("content_rating"),
  streamingUrl: text("streaming_url"),
  externalSource: text("external_source"),
  status: text("status").default("active"),
  categoryId: integer("category_id"),
  subcategoryId: integer("subcategory_id"),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertMovieSchema = createInsertSchema(movies).omit({
  id: true,
  createdAt: true,
});

// Series schema
export const series = pgTable("series", {
  id: serial("id").primaryKey(),
  title: text("title").notNull(),
  description: text("description"),
  startYear: integer("start_year"),
  endYear: integer("end_year"),
  poster: text("poster"),
  backdrop: text("backdrop"),
  genre: text("genre"),
  contentRating: text("content_rating"),
  status: text("status").default("active"),
  categoryId: integer("category_id"),
  subcategoryId: integer("subcategory_id"),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertSeriesSchema = createInsertSchema(series).omit({
  id: true,
  createdAt: true,
});

// Episodes schema
export const episodes = pgTable("episodes", {
  id: serial("id").primaryKey(),
  seriesId: integer("series_id").notNull(),
  title: text("title").notNull(),
  description: text("description"),
  seasonNumber: integer("season_number").notNull(),
  episodeNumber: integer("episode_number").notNull(),
  streamingUrl: text("streaming_url"),
  thumbnail: text("thumbnail"),
  runtime: integer("runtime"),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertEpisodeSchema = createInsertSchema(episodes).omit({
  id: true,
  createdAt: true,
});

// Channels schema
export const channels = pgTable("channels", {
  id: serial("id").primaryKey(),
  name: text("name").notNull(),
  description: text("description"),
  logo: text("logo"),
  streamingUrl: text("streaming_url"),
  type: text("type"), // news, sports, entertainment, etc.
  status: text("status").default("active"),
  categoryId: integer("category_id"),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertChannelSchema = createInsertSchema(channels).omit({
  id: true,
  createdAt: true,
});

// Matches schema
export const matches = pgTable("matches", {
  id: serial("id").primaryKey(),
  title: text("title").notNull(),
  description: text("description"),
  startTime: timestamp("start_time"),
  endTime: timestamp("end_time"),
  thumbnail: text("thumbnail"),
  streamingUrl: text("streaming_url"),
  sport: text("sport"), // football, basketball, etc.
  competition: text("competition"), // UEFA Champions League, NBA, etc.
  status: text("status").default("scheduled"), // scheduled, live, completed, canceled
  categoryId: integer("category_id"),
  teamHome: text("team_home"), // Home team name
  teamAway: text("team_away"), // Away team name
  scoreHome: integer("score_home"), // Home team score
  scoreAway: integer("score_away"), // Away team score
  venue: text("venue"), // Stadium or venue name
  highlights: text("highlights"), // URL to highlights video
  externalId: text("external_id"), // ID from external source for tracking
  externalSource: text("external_source"), // Source of external data
  lastUpdated: timestamp("last_updated"), // When match data was last updated
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertMatchSchema = createInsertSchema(matches).omit({
  id: true,
  createdAt: true,
});

// Notifications schema
export const notifications = pgTable("notifications", {
  id: serial("id").primaryKey(),
  title: text("title").notNull(),
  message: text("message").notNull(),
  image: text("image"),
  link: text("link"),
  contentId: integer("content_id"),
  contentType: text("content_type"), // movie, series, channel, match
  type: text("type").default("info"), // info, warning, error, success
  read: boolean("read").default(false),
  createdAt: timestamp("created_at").defaultNow().notNull(),
});

export const insertNotificationSchema = createInsertSchema(notifications).omit({
  id: true,
  read: true,
  createdAt: true,
});

// Define types for the schemas
export type User = typeof users.$inferSelect;
export type InsertUser = z.infer<typeof insertUserSchema>;

export type Category = typeof categories.$inferSelect;
export type InsertCategory = z.infer<typeof insertCategorySchema>;

export type Subcategory = typeof subcategories.$inferSelect;
export type InsertSubcategory = z.infer<typeof insertSubcategorySchema>;

export type Movie = typeof movies.$inferSelect;
export type InsertMovie = z.infer<typeof insertMovieSchema>;

export type Series = typeof series.$inferSelect;
export type InsertSeries = z.infer<typeof insertSeriesSchema>;

export type Episode = typeof episodes.$inferSelect;
export type InsertEpisode = z.infer<typeof insertEpisodeSchema>;

export type Channel = typeof channels.$inferSelect;
export type InsertChannel = z.infer<typeof insertChannelSchema>;

export type Match = typeof matches.$inferSelect;
export type InsertMatch = z.infer<typeof insertMatchSchema>;

export type Notification = typeof notifications.$inferSelect;
export type InsertNotification = z.infer<typeof insertNotificationSchema>;

// Site Settings schema
export const siteSettings = pgTable("site_settings", {
  id: serial("id").primaryKey(),
  siteName: text("site_name").notNull(),
  siteDescription: text("site_description").notNull(),
  siteKeywords: text("site_keywords").notNull(),
  siteLogo: text("site_logo"),
  siteFavicon: text("site_favicon"),
  appFilePath: text("app_file_path"),
  appFileName: text("app_file_name"),
  appVersion: text("app_version"),
  playerVersion: text("player_version"),
  maintenance: boolean("maintenance").default(false).notNull(),
  updatedAt: timestamp("updated_at").defaultNow().notNull(),
});

export const insertSiteSettingsSchema = createInsertSchema(siteSettings).omit({
  id: true,
  updatedAt: true,
});

export type SiteSettings = typeof siteSettings.$inferSelect;
export type InsertSiteSettings = z.infer<typeof insertSiteSettingsSchema>;
